Struct BlockVector

pub struct BlockVector { /* private fields */ }
Block vector.

``ascii

| A | | . | | . | | A |

| B | | . | | . | | B |

| | | * | | * | | |

| Z | | . | | . | | Z |

It ia split into regions and each region is split into a sequence of sub-vectors. Within each region, all sub-vectors have the same dimension. E.g., region 0 contains only A-dimensional sub-vectors, region 1 contains only B-dimensional sub-vectors, etc.

Implementations

Source

impl BlockVector

pub fn zero(partition_specs: &[PartitionSpec]) -> Self

Create a block vector filled with zeros.

The shape of the block vector is determined by the provided partition specs.

pub fn fill(&mut self, value: f64)

Fill vector with a constant value.

pub fn into_scalar_vector(self) -> DVector<f64>

Move out of self and return scalar vector representation.

pub fn scalar_vector(&self) -> &DVector<f64>

Get the scalar vector representation.

pub fn scalar_vector_mut(&mut self) -> &mut DVector<f64>

Get the scalar vector representation.

pub fn add_block( &mut self, partition_idx: usize, block_index: usize, block: &DVectorView<'_, f64>, )

Add a block to the vector.

pub fn get_block( &self, partition_idx: usize, block_index: usize, ) -> DVectorView<'_, f64>

Get a block