pub struct BlockVector { /* private fields */ }Expand description
Block vector.
``ascii
| A | | . | | . | | A |
| B | | . | | . | | B |
| | | * | | * | | |
| Z | | . | | . | | Z |
It ia split into regions and each region is split into a sequence of sub-vectors. Within each region, all sub-vectors have the same dimension. E.g., region 0 contains only A-dimensional sub-vectors, region 1 contains only B-dimensional sub-vectors, etc.
Implementations
Sourceimpl BlockVector
impl BlockVector
Sourcepub fn zero(partition_specs: &[PartitionSpec]) -> Self
pub fn zero(partition_specs: &[PartitionSpec]) -> Self
Create a block vector filled with zeros.
The shape of the block vector is determined by the provided partition specs.
Sourcepub fn into_scalar_vector(self) -> DVector<f64>
pub fn into_scalar_vector(self) -> DVector<f64>
Move out of self and return scalar vector representation.
Sourcepub fn scalar_vector(&self) -> &DVector<f64>
pub fn scalar_vector(&self) -> &DVector<f64>
Get the scalar vector representation.
Sourcepub fn scalar_vector_mut(&mut self) -> &mut DVector<f64>
pub fn scalar_vector_mut(&mut self) -> &mut DVector<f64>
Get the scalar vector representation.